@@ -18,7 +18,6 @@ import os
 import sys
 import simplejson as json
 
-import fabric
 from fabric.api import *
 from fabric.contrib.files import append, exists
 from fabric.contrib.console import confirm
@@ -32,8 +31,10 @@ from littlechef.settings import cookbook_paths
 
 
 # Fabric settings
-env.loglevel = "info"
+import fabric
 fabric.state.output['running'] = False
+env.loglevel = "info"
+env.output_prefix = False
 
 
 @hosts('setup')
@@ -93,14 +94,21 @@ def deploy_chef(gems="no", ask="yes", version="0.9"):
         abort('Wrong Chef version specified. Valid versions are {0}'.format(
             ", ".join(chef_versions)))
     distro_type, distro = solo.check_distro()
-    message = '\nAre you sure you want to install Chef at the node {0}'.format(
-        env.host_string)
-    if gems == "yes":
-        message += ', using gems for "{0}"?'.format(distro)
+    if ask == "yes":
+        message = '\nAre you sure you want to install Chef at the node {0}'.format(
+            env.host_string)
+        if gems == "yes":
+            message += ', using gems for "{0}"?'.format(distro)
+        else:
+            message += ', using "{0}" packages?'.format(distro)
+        if not confirm(message):
+            abort('Aborted by user')
     else:
-        message += ', using "{0}" packages?'.format(distro)
-    if ask != "no" and not confirm(message):
-        abort('Aborted by user')
+        if gems == "yes":
+            method = ' using gems for "{0}"'.format(distro)
+        else:
+            method = ' {0} using "{1}" packages'.format(version, distro)
+        print("Deploying Chef {0}...".format(method))
 
     solo.install(distro_type, distro, gems, version)
     solo.configure()
@@ -255,6 +263,7 @@ def _readconfig():
 
     # We expect an ssh_config file here,
     # and/or a user, (password/keyfile) pair
+    env.ssh_config = None
     try:
         ssh_config = config.get('userinfo', 'ssh-config')
     except ConfigParser.NoSectionError:
@@ -275,8 +284,6 @@ def _readconfig():
         except Exception:
             msg = "Couldn't parse the ssh-config file '{0}'".format(ssh_config)
             abort(msg)
-    else:
-        env.ssh_config = None
 
     try:
         env.user = config.get('userinfo', 'user')
@@ -311,4 +318,4 @@ if littlechef.COOKING:
          _readconfig()
 else:
     # runner module has been imported
-    pass
+    env.ssh_config = None
